@@ -1,10 +1,13 @@
 package bodybuilder.inspector;
 
 import java.util.Iterator;
+import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
+import bodybuilder.util.Config;
 import bodybuilder.util.ExtendedPropertyUtils;
+import bodybuilder.util.ObjectUtils;
 
 /**
  * ビーンインスペクター
@@ -23,14 +26,30 @@ public class BeanInspector extends Inspector {
         // プロパティを取得。
         Map expectedProps = ExtendedPropertyUtils.getProperties(expected);
         Map actualProps = ExtendedPropertyUtils.getProperties(actual);
+
         // プロパティ名を検査。
         Set expectedNameSet = expectedProps.keySet();
         assertKeySetEquals(expectedNameSet, actualProps.keySet(), trace);
         Iterator names = expectedNameSet.iterator();
 
+        // 検査しないプロパティのリストを取得。
+        String type = expected.getClass().getName();
+        String pkg = ObjectUtils.getPackage(type, true);
+        Map ignores = Config.getIgnoreProperties();
+        List ignoreProps = (List) ignores.get(type);
+
+        if (ignoreProps == null) {
+            ignoreProps = (List) ignores.get(pkg);
+        }
+
         // プロパティ値を検査。
         while (names.hasNext()) {
             Object name = names.next();
+
+            if (ignoreProps != null && ignoreProps.contains(name)) {
+                continue;
+            }
+
             trace.appendKey(name);
             Object expectedElement = expectedProps.get(name);
             Object actualElement = actualProps.get(name);
