@@ -120,6 +120,26 @@ public class Config {
                 + "exception.cause", false);
     }
 
+    /**
+     * 検査しないプロパティのマップを取得する。
+     * 
+     * @return 検査しないプロパティのマップ
+     */
+    public static Map getIgnoreProperties() {
+        String[] cpvals = getList(getProperty(INSPECTION_PROP_KEY_PRIFIX
+                + "ignore.properties"));
+        Map ignores = new HashMap();
+
+        for (int i = 0; i < cpvals.length; i++) {
+            String[] divided = cpvals[i].split("[#/]");
+            List props = new ArrayList(Arrays.asList(divided));
+            props.remove(0);
+            ignores.put(divided[0], props);
+        }
+
+        return ignores;
+    }
+
     /////////////////////////////////////////////////////////////////
     // view property
 
